<!-- markdownlint-disable -->

<a href="../spherapy/util/exceptions.py#L0"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

# <kbd>module</kbd> `util.exceptions`
Generic exceptions that apply throughout satplot. 



---

<a href="../spherapy/util/exceptions.py#L3"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

## <kbd>class</kbd> `OutOfRangeError`
The value is out of the acceptable range. 





---

<a href="../spherapy/util/exceptions.py#L6"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

## <kbd>class</kbd> `DimensionError`
Dimension of an array is invalid. 







---

_This file was automatically generated via [lazydocs](https://github.com/ml-tooling/lazydocs)._
